var compat__check_8hpp =
[
    [ "uhd::compat_num&lt; major_type, minor_type &gt;", "classuhd_1_1compat__num.html", "classuhd_1_1compat__num" ],
    [ "uhd::compat_num16", "classuhd_1_1compat__num16.html", "classuhd_1_1compat__num16" ],
    [ "uhd::compat_num32", "classuhd_1_1compat__num32.html", "classuhd_1_1compat__num32" ],
    [ "uhd::assert_fpga_compat", "namespaceuhd.html#a175992e0a0505a09269fa407651383fe", null ],
    [ "uhd::assert_fpga_compat", "namespaceuhd.html#ad653d5a22f37fe302496d5bcb39f4c0f", null ]
];